@@ -96,6 +96,7 @@ fn codegen_expr(expr: &Expr) -> Value {
                 BinOp::Sub => Value::symbol("-"),
                 BinOp::Mul => Value::symbol("*"),
                 BinOp::Div => Value::symbol("/"),
+                BinOp::Mod => Value::symbol("%"),
                 BinOp::Append => {
                     if x.itype
                         .deunionize()
@@ -111,6 +112,11 @@ fn codegen_expr(expr: &Expr) -> Value {
                 BinOp::Le => Value::symbol("<="),
                 BinOp::Gt => Value::symbol(">"),
                 BinOp::Ge => Value::symbol(">="),
+                BinOp::Bor => Value::symbol("or"),
+                BinOp::Band => Value::symbol("and"),
+                BinOp::Bxor => Value::symbol("xor"),
+                BinOp::Lshift => Value::symbol("<<"),
+                BinOp::Rshift => Value::symbol(">>"),
             };
             let x = codegen_expr(x);
             let y = codegen_expr(y);
