@@ -108,11 +108,19 @@ pub enum BinOp {
     Sub,
     Mul,
     Div,
+    Mod,
 
     Lor,
     Land,
     Lnot,
 
+    Bor,
+    Band,
+    Bxor,
+
+    Lshift,
+    Rshift,
+
     Append,
 
     Eq,
